@@ -12,27 +12,8 @@
 
 #include "soup-headers.h"
 #include "soup-misc.h"
-#include "soup-uri.h"
 
-/**
- * soup_headers_parse:
- * @str: the header string (including the Request-Line or Status-Line,
- * and the trailing blank line)
- * @len: length of @str up to (but not including) the terminating blank line.
- * @dest: #SoupMessageHeaders to store the header values in
- *
- * Parses the headers of an HTTP request or response in @str and
- * stores the results in @dest. Beware that @dest may be modified even
- * on failure.
- *
- * This is a low-level method; normally you would use
- * soup_headers_parse_request() or soup_headers_parse_response().
- *
- * Return value: success or failure
- *
- * Since: 2.26
- **/
-gboolean
+static gboolean
 soup_headers_parse (const char *str, int len, SoupMessageHeaders *dest)
 {
 	const char *headers_start;
@@ -40,9 +21,6 @@ soup_headers_parse (const char *str, int len, SoupMessageHeaders *dest)
 	char *eol, *sol;
 	gboolean success = FALSE;
 
-	g_return_val_if_fail (str != NULL, FALSE);
-	g_return_val_if_fail (dest != NULL, FALSE);
-
 	/* Technically, the grammar does allow NUL bytes in the
 	 * headers, but this is probably a bug, and if it's not, we
 	 * can't deal with them anyway.
@@ -70,24 +48,15 @@ soup_headers_parse (const char *str, int len, SoupMessageHeaders *dest)
 	while (*(value_end + 1)) {
 		name = value_end + 1;
 		name_end = strchr (name, ':');
-		if (!name_end || name + strcspn (name, " \t\r\n") < name_end) {
-			/* Bad header; just ignore this line. Note
-			 * that if it has continuation lines, we'll
-			 * end up ignoring them too since they'll
-			 * start with spaces.
-			 */
-			value_end = strchr (name, '\n');
-			if (!value_end)
-				goto done;
-			continue;
-		}
+		if (!name_end)
+			goto done;
 
 		/* Find the end of the value; ie, an end-of-line that
 		 * isn't followed by a continuation line.
 		 */
 		value = name_end + 1;
 		value_end = strchr (name, '\n');
-		if (!value_end)
+		if (!value_end || value_end < name_end)
 			goto done;
 		while (*(value_end + 1) == ' ' || *(value_end + 1) == '\t') {
 			value_end = strchr (value_end + 1, '\n');
@@ -143,7 +112,7 @@ soup_headers_clean_for_10 (SoupMessageHeaders *hdrs)
 	const char *connection;
 	GSList *tokens, *t;
 
-	connection = soup_message_headers_get_list (hdrs, "Connection");
+	connection = soup_message_headers_get (hdrs, "Connection");
 	if (!connection)
 		return;
 
@@ -188,12 +157,10 @@ soup_headers_parse_request (const char          *str,
 	/* RFC 2616 4.1 "servers SHOULD ignore any empty line(s)
 	 * received where a Request-Line is expected."
 	 */
-	while ((*str == '\r' || *str == '\n') && len > 0) {
+	while (*str == '\r' || *str == '\n') {
 		str++;
 		len--;
 	}
-	if (!len)
-		return SOUP_STATUS_BAD_REQUEST;
 
 	/* RFC 2616 19.3 "[servers] SHOULD accept any amount of SP or
 	 * HT characters between [Request-Line] fields"
@@ -233,7 +200,7 @@ soup_headers_parse_request (const char          *str,
 	version_end = p;
 	if (major_version != 1)
 		return SOUP_STATUS_HTTP_VERSION_NOT_SUPPORTED;
-	if (minor_version > 1)
+	if (minor_version < 0 || minor_version > 1)
 		return SOUP_STATUS_HTTP_VERSION_NOT_SUPPORTED;
 
 	headers = version_end;
@@ -285,8 +252,6 @@ soup_headers_parse_status_line (const char       *status_line,
 	const char *code_start, *code_end, *phrase_start, *phrase_end;
 	char *p;
 
-	g_return_val_if_fail (status_line != NULL, FALSE);
-
 	if (strncmp (status_line, "HTTP/", 5) == 0 &&
 	    g_ascii_isdigit (status_line[5])) {
 		major_version = strtoul (status_line + 5, &p, 10);
@@ -295,14 +260,13 @@ soup_headers_parse_status_line (const char       *status_line,
 		minor_version = strtoul (p + 1, &p, 10);
 		if (major_version != 1)
 			return FALSE;
-		if (minor_version > 1)
+		if (minor_version < 0 || minor_version > 1)
 			return FALSE;
 		if (ver)
 			*ver = (minor_version == 0) ? SOUP_HTTP_1_0 : SOUP_HTTP_1_1;
 	} else if (!strncmp (status_line, "ICY", 3)) {
 		/* Shoutcast not-quite-HTTP format */
-		if (ver)
-			*ver = SOUP_HTTP_1_0;
+		*ver = SOUP_HTTP_1_0;
 		p = (char *)status_line + 3;
 	} else
 		return FALSE;
@@ -361,17 +325,7 @@ soup_headers_parse_response (const char          *str,
 {
 	SoupHTTPVersion version;
 
-	g_return_val_if_fail (str && *str, FALSE);
-
-	/* Workaround for broken servers that send extra line breaks
-	 * after a response, which we then see prepended to the next
-	 * response on that connection.
-	 */
-	while ((*str == '\r' || *str == '\n') && len > 0) {
-		str++;
-		len--;
-	}
-	if (!len)
+	if (!str || !*str)
 		return FALSE;
 
 	if (!soup_headers_parse (str, len, headers)) 
@@ -477,8 +431,6 @@ parse_list (const char *header, char delim)
 GSList *
 soup_header_parse_list (const char *header)
 {
-	g_return_val_if_fail (header != NULL, NULL);
-
 	return parse_list (header, ',');
 }
 
@@ -529,8 +481,6 @@ soup_header_parse_quality_list (const char *header, GSList **unacceptable)
 	double qval;
 	int n;
 
-	g_return_val_if_fail (header != NULL, NULL);
-
 	if (unacceptable)
 		*unacceptable = NULL;
 
@@ -625,9 +575,6 @@ soup_header_contains (const char *header, const char *token)
 	const char *end;
 	guint len = strlen (token);
 
-	g_return_val_if_fail (header != NULL, FALSE);
-	g_return_val_if_fail (token != NULL, FALSE);
-
 	header = skip_delims (header, ',');
 	while (*header) {
 		end = skip_item (header, ',');
@@ -655,29 +602,6 @@ decode_quoted_string (char *quoted_string)
 	*dst = '\0';
 }
 
-static gboolean
-decode_rfc2231 (char *encoded_string)
-{
-	char *q, *decoded;
-
-	q = strchr (encoded_string, '\'');
-	if (!q)
-		return FALSE;
-	if (g_ascii_strncasecmp (encoded_string, "UTF-8",
-				 q - encoded_string) != 0)
-		return FALSE;
-
-	q = strchr (q + 1, '\'');
-	if (!q)
-		return FALSE;
-
-	decoded = soup_uri_decode (q + 1);
-	/* strlen(decoded) <= strlen(q + 1) < strlen(encoded_string) */
-	strcpy (encoded_string, decoded);
-	g_free (decoded);
-	return TRUE;
-}
-
 static GHashTable *
 parse_param_list (const char *header, char delim)
 {
@@ -708,14 +632,7 @@ parse_param_list (const char *header, char delim)
 			*name_end = '\0';
 
 			value = (char *)skip_lws (eq + 1);
-
-			if (name_end[-1] == '*' && name_end > item + 1) {
-				name_end[-1] = '\0';
-				if (!decode_rfc2231 (value)) {
-					g_free (item);
-					continue;
-				}
-			} else if (*value == '"')
+			if (*value == '"')
 				decode_quoted_string (value);
 		} else
 			value = NULL;
@@ -731,24 +648,18 @@ parse_param_list (const char *header, char delim)
  * soup_header_parse_param_list:
  * @header: a header value
  *
- * Parses a header which is a comma-delimited list of something like:
- * <literal>token [ "=" ( token | quoted-string ) ]</literal>.
+ * Parses a header which is a comma-delimited list of something like
+ *
+ *   token [ "=" ( token | quoted-string ) ]
  *
  * Tokens that don't have an associated value will still be added to
  * the resulting hash table, but with a %NULL value.
  * 
- * This also handles RFC2231 encoding (which in HTTP is mostly used
- * for giving UTF8-encoded filenames in the Content-Disposition
- * header).
- *
- * Return value: a #GHashTable of list elements, which can be freed
- * with soup_header_free_param_list().
+ * Return value: a #GHashTable of list elements.
  **/
 GHashTable *
 soup_header_parse_param_list (const char *header)
 {
-	g_return_val_if_fail (header != NULL, NULL);
-
 	return parse_param_list (header, ',');
 }
 
@@ -757,146 +668,29 @@ soup_header_parse_param_list (const char *header)
  * @header: a header value
  *
  * Parses a header which is a semicolon-delimited list of something
- * like: <literal>token [ "=" ( token | quoted-string ) ]</literal>.
+ * like
+ *
+ *   token [ "=" ( token | quoted-string ) ]
  *
  * Tokens that don't have an associated value will still be added to
  * the resulting hash table, but with a %NULL value.
  * 
- * This also handles RFC2231 encoding (which in HTTP is mostly used
- * for giving UTF8-encoded filenames in the Content-Disposition
- * header).
- *
- * Return value: a #GHashTable of list elements, which can be freed
- * with soup_header_free_param_list().
- *
- * Since: 2.24
+ * Return value: a #GHashTable of list elements.
  **/
 GHashTable *
 soup_header_parse_semi_param_list (const char *header)
 {
-	g_return_val_if_fail (header != NULL, NULL);
-
 	return parse_param_list (header, ';');
 }
 
 /**
  * soup_header_free_param_list:
  * @param_list: a #GHashTable returned from soup_header_parse_param_list()
- * or soup_header_parse_semi_param_list()
  *
  * Frees @param_list.
  **/
 void
 soup_header_free_param_list (GHashTable *param_list)
 {
-	g_return_if_fail (param_list != NULL);
-
 	g_hash_table_destroy (param_list);
 }
-
-static void
-append_param_rfc2231 (GString    *string,
-		      const char *name,
-		      const char *value)
-{
-	char *encoded;
-
-	g_string_append (string, name);
-	g_string_append (string, "*=UTF-8''");
-	encoded = soup_uri_encode (value, " *'%()<>@,;:\\\"/[]?=");
-	g_string_append (string, encoded);
-	g_free (encoded);
-}
-
-/**
- * soup_header_g_string_append_param_quoted:
- * @string: a #GString being used to construct an HTTP header value
- * @name: a parameter name
- * @value: a parameter value
- *
- * Appends something like <literal>@name="@value"</literal> to
- * @string, taking care to escape any quotes or backslashes in @value.
- *
- * Since: 2.32
- **/
-void
-soup_header_g_string_append_param_quoted (GString    *string,
-					  const char *name,
-					  const char *value)
-{
-	int len;
-
-	g_return_if_fail (string != NULL);
-	g_return_if_fail (name != NULL);
-	g_return_if_fail (value != NULL);
-
-	g_string_append (string, name);
-	g_string_append (string, "=\"");
-	while (*value) {
-		while (*value == '\\' || *value == '"') {
-			g_string_append_c (string, '\\');
-			g_string_append_c (string, *value++);
-		}
-		len = strcspn (value, "\\\"");
-		g_string_append_len (string, value, len);
-		value += len;
-	}
-	g_string_append_c (string, '"');
-}
-
-/**
- * soup_header_g_string_append_param:
- * @string: a #GString being used to construct an HTTP header value
- * @name: a parameter name
- * @value: a parameter value, or %NULL
- *
- * Appends something like <literal>@name=@value</literal> to @string,
- * taking care to quote @value if needed, and if so, to escape any
- * quotes or backslashes in @value.
- *
- * Alternatively, if @value is a non-ASCII UTF-8 string, it will be
- * appended using RFC2231 syntax. Although in theory this is supposed
- * to work anywhere in HTTP that uses this style of parameter, in
- * reality, it can only be used portably with the Content-Disposition
- * "filename" parameter.
- *
- * If @value is %NULL, this will just append @name to @string.
- *
- * Since: 2.26
- **/
-void
-soup_header_g_string_append_param (GString    *string,
-				   const char *name,
-				   const char *value)
-{
-	const char *v;
-	gboolean token = TRUE;
-
-	g_return_if_fail (string != NULL);
-	g_return_if_fail (name != NULL);
-
-	if (!value) {
-		g_string_append (string, name);
-		return;
-	}
-
-	for (v = value; *v; v++) {
-		if (*v & 0x80) {
-			if (g_utf8_validate (value, -1, NULL)) {
-				append_param_rfc2231 (string, name, value);
-				return;
-			} else {
-				token = FALSE;
-				break;
-			}
-		} else if (!soup_char_is_token (*v))
-			token = FALSE;
-	}
-
-	if (token) {
-		g_string_append (string, name);
-		g_string_append_c (string, '=');
-		g_string_append (string, value);
-	} else
-		soup_header_g_string_append_param_quoted (string, name, value);
-}
